yt.fields.xray\_emission\_fields module
=======================================

.. automodule:: yt.fields.xray_emission_fields
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
